
import random
from django.core.cache import cache
from django.utils.timezone import now
from django.db.models import Sum

def calculate_total_orders_per_day():
    """
    Calculate the total number of orders per day from the database.
    """
    # Use Django ORM to query the database
    from myapp.models import Order
    total_orders_per_day = Order.objects.annotate(
        total=Sum('quantity')
    ).values('order_date').annotate(
        total_orders=Sum('total')
    )

    # Cache the result to improve performance
    cache_key = 'total_orders_per_day'
    cache.set(cache_key, total_orders_per_day, timeout=60*60)

    return total_orders_per_day



